# Importar los métodos desde los módulos correspondientes
from .nonlinear.bisection import bisection_method
from .linear.gauss_jordan import gauss_jordan
from .linear.gauss_elimination import gauss_elimination
from .linear.cramer_rule import cramer_rule
from .linear.lu_decomposition import lu_decomposition
from .nonlinear.jacobi import jacobi_method
from .nonlinear.gauss_seidel import gauss_seidel